#!/bin/bash
#
# file /etc/sysconfig/iptable_ppp.sh - Initial IP Firewall script for 2.4.x
#
# Author: Vladimir Kholmanov, changes Eugene Prokopiev
# use at your own risk
#
################################################################################
EXTERNAL_IFACE_1="eth0"
EXTERNAL_IFACE_2="ppp7"
#INTERNAL_IFACE="eth0"
LOCAL_IFACE="lo"
IPTABLES="/sbin/iptables"
################################################################################
#     IPTables modules
#
/sbin/depmod -a
#
################################################################################
#  default policies  INPUT, FORWARD  OUTPUT chains
#
$IPTABLES -P INPUT DROP
$IPTABLES -P OUTPUT ACCEPT
$IPTABLES -P FORWARD ACCEPT
################################################################################
#   chains  ICMP, TCP  UDP .
#
$IPTABLES -N icmp_in_ppp
$IPTABLES -N tcp_in_ppp
$IPTABLES -N udp_in_ppp
################################################################################
#  ICMP rules   
#
$IPTABLES -A icmp_in_ppp -p ICMP --icmp-type 3 -j ACCEPT
$IPTABLES -A icmp_in_ppp -p ICMP --icmp-type 0 -j ACCEPT
$IPTABLES -A icmp_in_ppp -p ICMP --icmp-type 11 -j ACCEPT
$IPTABLES -A icmp_in_ppp -m limit --limit 6/minute --limit-burst 1 -p ICMP --icmp-type 8 -j ACCEPT
$IPTABLES -A icmp_in_ppp -m limit --limit 2/minute --limit-burst 4 -j LOG --log-prefix "ICMP in ppp died: "
$IPTABLES -A icmp_in_ppp -p ICMP -j DROP
################################################################################
#  TCP rules   
#
$IPTABLES -A tcp_in_ppp -p TCP --syn --dport 80 -j ACCEPT
$IPTABLES -A tcp_in_ppp -p TCP --syn --dport 22 -j ACCEPT
$IPTABLES -A tcp_in_ppp -p TCP --syn --dport 53 -j ACCEPT
$IPTABLES -A tcp_in_ppp -p TCP --syn --dport 123 -j ACCEPT
$IPTABLES -A tcp_in_ppp -p TCP --syn --dport 6000 -j DROP
$IPTABLES -A tcp_in_ppp -p TCP --syn --dport 1024:65535 -j ACCEPT
$IPTABLES -A tcp_in_ppp -p TCP -m state --state ESTABLISHED,RELATED -j ACCEPT
$IPTABLES -A tcp_in_ppp -m limit --limit 2/minute --limit-burst 4 -j LOG --log-prefix "TCP in ppp died: "
$IPTABLES -A tcp_in_ppp -p TCP -j DROP
################################################################################
#  UDP rules   
#
$IPTABLES -A udp_in_ppp -p UDP --dport 53 -j ACCEPT
$IPTABLES -A udp_in_ppp -p UDP --dport 123 -j ACCEPT
$IPTABLES -A udp_in_ppp -p UDP --dport 1024:65535 -j ACCEPT
$IPTABLES -A udp_in_ppp -m limit --limit 3/minute --limit-burst 6 -j LOG --log-prefix "UDP in ppp died: "
$IPTABLES -A udp_in_ppp -p UDP -j DROP
################################################################################
# INPUT chain
#
#    "" TCP .
#
$IPTABLES -A INPUT -i $EXTERNAL_IFACE -p tcp ! --syn -m state --state NEW -j LOG --log-prefix "New not syn:"
$IPTABLES -A INPUT -i $EXTERNAL_IFACE -p tcp ! --syn -m state --state NEW -j DROP
################################################################################
# ""    ""  inet  rules.
#
$IPTABLES -A INPUT -p TCP -i $LOCAL_IFACE -j ACCEPT
#$IPTABLES -A INPUT -p TCP -i $INTERNAL_IFACE -j ACCEPT
$IPTABLES -A INPUT -p TCP -i $EXTERNAL_IFACE_1 -j tcp_in_ppp
$IPTABLES -A INPUT -p TCP -i $EXTERNAL_IFACE_2 -j tcp_in_ppp

$IPTABLES -A INPUT -p UDP -i $LOCAL_IFACE -j ACCEPT
#$IPTABLES -A INPUT -p UDP -i $INTERNAL_IFACE -j ACCEPT
$IPTABLES -A INPUT -p UDP -i $EXTERNAL_IFACE_1 -j udp_in_ppp
$IPTABLES -A INPUT -p UDP -i $EXTERNAL_IFACE_2 -j udp_in_ppp

$IPTABLES -A INPUT -p ICMP -i $LOCAL_IFACE -j ACCEPT
#$IPTABLES -A INPUT -p ICMP -i $INTERNAL_IFACE -j ACCEPT
$IPTABLES -A INPUT -p ICMP -i $EXTERNAL_IFACE_1 -j icmp_in_ppp
$IPTABLES -A INPUT -p ICMP -i $EXTERNAL_IFACE_2 -j icmp_in_ppp
################################################################################
#  rule  "" .
#
$IPTABLES -A INPUT -m limit --limit 10/minute --limit-burst 6 -j LOG --log-prefix "IP INPUT packet died: "
################################################################################
#   NAT
#
$IPTABLES -A OUTPUT -m state -p icmp --state INVALID -j DROP


##if [ $PPPOE_PMTU == "yes" ] ; then
#   $IPTABLES -t nat -A POSTROUTING -p tcp --tcp-flags SYN,RST SYN \
#   -j TCPMSS --clamp-mss-to-pmtu
#fi
#$IPTABLES -t nat -P POSTROUTING DROP
#$IPTABLES -t nat -A POSTROUTING -o $EXTERNAL_IFACE -j MASQUERADE
